@@ -7,7 +7,6 @@ import (
 	. "github.com/onsi/gomega"
 
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
-	instanceutils "github.com/weaveworks/eksctl/pkg/utils/instance"
 )
 
 var _ = Describe("GPU instance support", func() {
@@ -22,11 +21,7 @@ var _ = Describe("GPU instance support", func() {
 	assertValidationError := func(e gpuInstanceEntry, err error) {
 		if e.expectUnsupportedErr {
 			Expect(err).To(HaveOccurred())
-			if instanceutils.IsNvidiaInstanceType(e.gpuInstanceType) {
-				Expect(err).To(MatchError(ContainSubstring(fmt.Sprintf("GPU instance types are not supported for %s", e.amiFamily))))
-			} else {
-				Expect(err).To(MatchError(ContainSubstring(fmt.Sprintf("Inferentia instance types are not supported for %s", e.amiFamily))))
-			}
+			Expect(err).To(MatchError(ContainSubstring(fmt.Sprintf("Inferentia instance types are not supported for %s", e.amiFamily))))
 			return
 		}
 		Expect(err).NotTo(HaveOccurred())
@@ -48,9 +43,8 @@ var _ = Describe("GPU instance support", func() {
 			amiFamily:       api.NodeImageFamilyAmazonLinux2,
 		}),
 		Entry("Ubuntu2004", gpuInstanceEntry{
-			amiFamily:            api.NodeImageFamilyUbuntu2004,
-			gpuInstanceType:      "g4dn.xlarge",
-			expectUnsupportedErr: true,
+			amiFamily:       api.NodeImageFamilyUbuntu2004,
+			gpuInstanceType: "g4dn.xlarge",
 		}),
 		Entry("Bottlerocket", gpuInstanceEntry{
 			amiFamily:            api.NodeImageFamilyBottlerocket,
@@ -95,19 +89,16 @@ var _ = Describe("GPU instance support", func() {
 			gpuInstanceType: "g4dn.xlarge",
 		}),
 		Entry("Ubuntu2004", gpuInstanceEntry{
-			amiFamily:            api.NodeImageFamilyUbuntu2004,
-			gpuInstanceType:      "g4dn.xlarge",
-			expectUnsupportedErr: true,
+			amiFamily:       api.NodeImageFamilyUbuntu2004,
+			gpuInstanceType: "g4dn.xlarge",
 		}),
 		Entry("Windows2019Core", gpuInstanceEntry{
-			amiFamily:            api.NodeImageFamilyWindowsServer2019CoreContainer,
-			gpuInstanceType:      "g3.8xlarge",
-			expectUnsupportedErr: true,
+			amiFamily:       api.NodeImageFamilyWindowsServer2019CoreContainer,
+			gpuInstanceType: "g3.8xlarge",
 		}),
 		Entry("Windows2019Full", gpuInstanceEntry{
-			amiFamily:            api.NodeImageFamilyWindowsServer2019FullContainer,
-			gpuInstanceType:      "p3.2xlarge",
-			expectUnsupportedErr: true,
+			amiFamily:       api.NodeImageFamilyWindowsServer2019FullContainer,
+			gpuInstanceType: "p3.2xlarge",
 		}),
 	)
 	Describe("ARM GPU", func() {
