@@ -1894,7 +1894,7 @@ var _ = Describe("ClusterConfig validation", func() {
 			cfg.Karpenter = &api.Karpenter{
 				Version: "0.6.1",
 			}
-			Expect(api.ValidateClusterConfig(cfg)).To(MatchError(ContainSubstring("failed to validate karpenter config: iam.withOIDC must be enabled with Karpenter")))
+			Expect(api.ValidateClusterConfig(cfg)).To(MatchError(ContainSubstring("failed to validate Karpenter config: iam.withOIDC must be enabled with Karpenter")))
 		})
 
 		It("returns an error when version is missing", func() {
@@ -1909,16 +1909,16 @@ var _ = Describe("ClusterConfig validation", func() {
 			cfg.Karpenter = &api.Karpenter{
 				Version: "isitmeeeyourlookingfoorrrr",
 			}
-			Expect(api.ValidateClusterConfig(cfg)).To(MatchError(ContainSubstring("failed to parse karpenter version")))
+			Expect(api.ValidateClusterConfig(cfg)).To(MatchError(ContainSubstring("failed to parse Karpenter version")))
 		})
 
 		It("returns an error when the version is not supported", func() {
 			cfg := api.NewClusterConfig()
 			cfg.IAM.WithOIDC = aws.Bool(true)
 			cfg.Karpenter = &api.Karpenter{
-				Version: "0.10.0",
+				Version: "0.16.1",
 			}
-			Expect(api.ValidateClusterConfig(cfg)).To(MatchError(ContainSubstring("failed to validate karpenter config: maximum supported version is 0.9")))
+			Expect(api.ValidateClusterConfig(cfg)).To(MatchError(ContainSubstring("failed to validate Karpenter config: maximum supported version is 0.15.0")))
 		})
 	})
 
