@@ -65,7 +65,7 @@ func doDeleteCluster(cmd *cmdutils.Cmd, force bool, disableNodegroupEviction boo
 	cfg := cmd.ClusterConfig
 	meta := cmd.ClusterConfig.Metadata
 	printer := printers.NewJSONPrinter()
-	ctx := context.TODO()
+	ctx := context.Background()
 	ctl, err := cmd.NewProviderForExistingCluster(ctx)
 	if err != nil {
 		if !force {
@@ -92,5 +92,5 @@ func doDeleteCluster(cmd *cmdutils.Cmd, force bool, disableNodegroupEviction boo
 
 	// ProviderConfig.WaitTimeout is not respected by cluster.Delete, which means the operation will never time out.
 	// When this is fixed, a deadline-based Context can be used here.
-	return cluster.Delete(context.TODO(), time.Second*20, podEvictionWaitPeriod, cmd.Wait, force, disableNodegroupEviction, parallel)
+	return cluster.Delete(ctx, 20*time.Second, podEvictionWaitPeriod, cmd.Wait, force, disableNodegroupEviction, parallel)
 }
