@@ -8,6 +8,7 @@ import (
 	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/aws/aws-sdk-go-v2/aws/retry"
 	"github.com/aws/aws-sdk-go-v2/service/cloudformation"
+	"github.com/aws/aws-sdk-go-v2/service/eks"
 	"github.com/aws/aws-sdk-go-v2/service/elasticloadbalancing"
 	"github.com/aws/aws-sdk-go-v2/service/elasticloadbalancingv2"
 	"github.com/aws/aws-sdk-go-v2/service/iam"
@@ -34,6 +35,7 @@ type ServicesV2 struct {
 	ssm                    *ssm.Client
 	iam                    *iam.Client
 	ec2                    *ec2.Client
+	eks                    *eks.Client
 }
 
 // STS implements the AWS STS service.
@@ -50,7 +52,7 @@ func (s *ServicesV2) STS() awsapi.STS {
 	return s.sts
 }
 
-// STSPresign provides a signed STS client for calls to Kubernetes.
+// STSPresigner provides a signed STS client for calls to Kubernetes.
 func (s *ServicesV2) STSPresigner() api.STSPresigner {
 	// set up sts client.
 	s.mu.Lock()
@@ -66,7 +68,7 @@ func (s *ServicesV2) STSPresigner() api.STSPresigner {
 	return s.stsPresigned
 }
 
-// CloudFormationV2 implements the AWS CloudFormation service.
+// CloudFormation implements the AWS CloudFormation service.
 func (s *ServicesV2) CloudFormation() awsapi.CloudFormation {
 	s.mu.Lock()
 	defer s.mu.Unlock()
@@ -135,3 +137,12 @@ func (s *ServicesV2) EC2() awsapi.EC2 {
 	}
 	return s.ec2
 }
+
+func (s *ServicesV2) EKS() awsapi.EKS {
+	s.mu.Lock()
+	defer s.mu.Unlock()
+	if s.eks == nil {
+		s.eks = eks.NewFromConfig(s.config)
+	}
+	return s.eks
+}
