@@ -8,17 +8,18 @@ import (
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
-	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
-	"github.com/weaveworks/eksctl/pkg/fargate/coredns"
-	"github.com/weaveworks/eksctl/pkg/testutils"
-	"github.com/weaveworks/eksctl/pkg/utils/names"
-	"github.com/weaveworks/eksctl/pkg/utils/retry"
 	appsv1 "k8s.io/api/apps/v1"
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	kubeclient "k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/kubernetes/fake"
+
+	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
+	"github.com/weaveworks/eksctl/pkg/fargate/coredns"
+	"github.com/weaveworks/eksctl/pkg/testutils"
+	"github.com/weaveworks/eksctl/pkg/utils/names"
+	"github.com/weaveworks/eksctl/pkg/utils/retry"
 )
 
 func TestFargateCoreDNS(t *testing.T) {
@@ -119,14 +120,14 @@ var _ = Describe("coredns", func() {
 		It("should set the compute-type annotation to 'fargate'", func() {
 			// Given:
 			mockClientset := mockClientsetWith(deployment("ec2", 0, 2))
-			deployment, err := mockClientset.AppsV1().Deployments(coredns.Namespace).Get(context.TODO(), coredns.Name, metav1.GetOptions{})
+			deployment, err := mockClientset.AppsV1().Deployments(coredns.Namespace).Get(context.Background(), coredns.Name, metav1.GetOptions{})
 			Expect(err).To(Not(HaveOccurred()))
 			Expect(deployment.Spec.Template.Annotations).To(HaveKeyWithValue(coredns.ComputeTypeAnnotationKey, "ec2"))
 			// When:
 			err = coredns.ScheduleOnFargate(mockClientset)
 			Expect(err).To(Not(HaveOccurred()))
 			// Then:
-			deployment, err = mockClientset.AppsV1().Deployments(coredns.Namespace).Get(context.TODO(), coredns.Name, metav1.GetOptions{})
+			deployment, err = mockClientset.AppsV1().Deployments(coredns.Namespace).Get(context.Background(), coredns.Name, metav1.GetOptions{})
 			Expect(err).To(Not(HaveOccurred()))
 			Expect(deployment.Spec.Template.Annotations).To(HaveKeyWithValue(coredns.ComputeTypeAnnotationKey, "fargate"))
 		})
